@@ -1,10 +1,11 @@
 INSTALLED_APPS = (
     'oauth_tokens',
+    'taggit',
 )
 
 OAUTH_TOKENS_VKONTAKTE_CLIENT_ID = 3430034
 OAUTH_TOKENS_VKONTAKTE_CLIENT_SECRET = 'b0FwzyKtO8QiQmgWQMTz'
-OAUTH_TOKENS_VKONTAKTE_SCOPE = ['ads,wall,photos,friends,stats']
+OAUTH_TOKENS_VKONTAKTE_SCOPE = ['ads,wall,photos,friends,stats,video']
 OAUTH_TOKENS_VKONTAKTE_USERNAME = '+919665223715'
 OAUTH_TOKENS_VKONTAKTE_PASSWORD = 'githubovich'
 OAUTH_TOKENS_VKONTAKTE_PHONE_END = '3715'
\ No newline at end of file
